library plugin;

uses
  Windows,
  PlugInHeader in 'PlugInHeader.pas'; //Global declarations

{$R *.RES}

////////////////////////////////////////////
//
// Required Plugin vars
//
////////////////////////////////////////////

const
 PlugInName = 'Test Plugin';

var
 AppEventProc : TEventProc;  //Call to cause an event within the Application
 SessionID    : Integer;

////////////////////////////////////////////
//
// Use SendEventToApp to easily send events
//  to your application
//
////////////////////////////////////////////

function SendEventToApp(const EventCode : LongWord; Params : Pointer) : Pointer;
begin
     Result:=AppEventProc(EventCode,SessionID,Params);
end;



////////////////////////////////////////////
//
// User methods
//
////////////////////////////////////////////

//Randomly choose a "status" string for application to display (Demonstrates string passing)
procedure GetStatus;
var
 St1, St2 : String;
// pStr : PChar;
begin
     //Assign St1,St2
     St1:='Doing fine!';
     St2:='not so good...';

     Randomize;

     IF (Random>0.5) then SendEventToApp(evaStatus,PChar(St1))
                     else SendEventToApp(evaStatus,PChar(St2));
end;

//Send an event that is not handled by the test application
procedure MakeError;
begin
     SendEventToApp(99999,nil);
end;

//Send an event with an invalid PluginID (Demonstrates importance of SessionID)
procedure MakeIDError;
begin
     AppEventProc(0,9999,nil);
end;


////////////////////////////////////////////
//
// Required Plugin EventHandler
//
//  (MUST be named according to PluginProcName
//   in PluginHeader)
//
////////////////////////////////////////////

// Handles all events from the Application
function EventHandler(const EventCode : LongWord; const PlugInID : Integer; Params : Pointer) : Pointer; stdcall;
begin
     Result:=nil;
     CASE EventCode of
       evpInit    :  begin //Initialization
                      AppEventProc:=TEventProc(Params); //Get Controller's EventHandler proc address
                      SessionID:=PlugInID; //Get SessionID, used to identify events from THIS plugin

                      //Pass it back this PlugIn's name
                      Result:=PChar(PlugInName);
                     end;
       evpAdd     :  begin
                      Result:=Pointer(PlugInID+Integer(Params));
                     end;
       evpStatus  : GetStatus;
       evpError   : MakeError;
       evpIDError : MakeIDError;
      else MessageBox(0,'Invalid EventCode','PlugIn',mb_ok);
      end;
end;

exports
 EventHandler;

begin
     AppEventProc:=nil; //test to make sure it is initialized
end.
